@@ -35,8 +35,8 @@ class Text(BaseModel):
         """
         validator: ensures only either the "content" or the "text" fields are present
         """
-        content, texts, mimeType = values.get("content"), values.get("texts"), values.get("mimeType")
-        if not (bool(content) ^ bool(texts)):
+        content, texts = values.get("content"), values.get("texts")
+        if content is None  and texts is None:
             raise ValueError('A structured text request must have either "content" or "texts" fields')
         if content:
             values["mimeType"] = "text/plain"
