@@ -379,9 +379,9 @@ class Service(Entity, NeedAuthentication):
             if check_file and len(request_input) < 256 and Path(request_input).is_file():
                 if request_type == "text":
                     request = TextRequest.from_file(request_input)
-                if request_type == "structuredText":
+                elif request_type == "structuredText":
                     request = StructuredTextRequest.from_file(request_input)
-                if request_type == "audio":
+                elif request_type == "audio":
                     request = AudioRequest.from_file(request_input)
                 else:
                     raise ValueError(
